# Chakri3 Twine Execution

A Python package to get basic maths by using calculator.

## Usage

Following query on terminal will provide you the addition, multiplication, divison and subtraction.

```
Add_number(223,143189) Sub_num(3,9) 
```